import { EventEmitterEventType } from '@fluid-internal/client-utils';
import { EventEmitterWithErrorHandling } from '@fluidframework/telemetry-utils';
import { IChannel } from '@fluidframework/datastore-definitions';
import { IChannelAttributes } from '@fluidframework/datastore-definitions';
import { IChannelServices } from '@fluidframework/datastore-definitions';
import { IChannelStorageService } from '@fluidframework/datastore-definitions';
import { IErrorEvent } from '@fluidframework/core-interfaces';
import { IEventProvider } from '@fluidframework/core-interfaces';
import { IEventThisPlaceHolder } from '@fluidframework/core-interfaces';
import { IExperimentalIncrementalSummaryContext } from '@fluidframework/runtime-definitions';
import { IFluidDataStoreRuntime } from '@fluidframework/datastore-definitions';
import { IFluidHandle } from '@fluidframework/core-interfaces';
import { IFluidHandleContext } from '@fluidframework/core-interfaces';
import { IGarbageCollectionData } from '@fluidframework/runtime-definitions';
import { ISequencedDocumentMessage } from '@fluidframework/protocol-definitions';
import { ISummaryTreeWithStats } from '@fluidframework/runtime-definitions';
import { ITelemetryContext } from '@fluidframework/runtime-definitions';
import { ITelemetryLoggerExt } from '@fluidframework/telemetry-utils';

/* Excluded from this release type: bindHandles */

/* Excluded from this release type: createSingleBlobSummary */

/* Excluded from this release type: EventEmitterWithErrorHandling */

/* Excluded from this release type: FluidSerializer */

/**
 * @public
 */
export declare interface IFluidSerializer {
    /**
     * Given a mostly-plain object that may have handle objects embedded within, will return a fully-plain object
     * where any embedded IFluidHandles have been replaced with a serializable form.
     *
     * The original `input` object is not mutated.  This method will shallowly clones all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     */
    encode(value: any, bind: IFluidHandle): any;
    /**
     * Given a fully-jsonable object tree that may have encoded handle objects embedded within, will return an
     * equivalent object tree where any encoded IFluidHandles have been replaced with their decoded form.
     *
     * The original `input` object is not mutated.  This method will shallowly clone all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     *
     * The decoded handles are implicitly bound to the handle context of this serializer.
     */
    decode(input: any): any;
    /**
     * Stringifies a given value. Converts any IFluidHandle to its stringified equivalent.
     */
    stringify(value: any, bind: IFluidHandle): string;
    /**
     * Parses the given JSON input string and returns the JavaScript object defined by it. Any Fluid
     * handles will be realized as part of the parse
     */
    parse(value: string): any;
}

/**
 * Base interface for shared objects from which other interfaces derive. Implemented by SharedObject
 * @public
 */
export declare interface ISharedObject<TEvent extends ISharedObjectEvents = ISharedObjectEvents> extends IChannel, IEventProvider<TEvent> {
    /**
     * Binds the given shared object to its containing data store runtime, causing it to attach once
     * the runtime attaches.
     */
    bindToContext(): void;
    /**
     * Returns the GC data for this shared object. It contains a list of GC nodes that contains references to
     * other GC nodes.
     * @param fullGC - true to bypass optimizations and force full generation of GC data.
     */
    getGCData(fullGC?: boolean): IGarbageCollectionData;
}

/**
 * Events emitted by {@link ISharedObject}.
 * @public
 */
export declare interface ISharedObjectEvents extends IErrorEvent {
    /**
     * Fires before an incoming operation (op) is applied to the shared object.
     *
     * @remarks Note: this should be considered an internal implementation detail. It is not recommended for external
     * use.
     *
     * @eventProperty
     */
    (event: "pre-op", listener: (op: ISequencedDocumentMessage, local: boolean, target: IEventThisPlaceHolder) => void): any;
    /**
     * Fires after an incoming op is applied to the shared object.
     *
     * @remarks Note: this should be considered an internal implementation detail. It is not recommended for external
     * use.
     *
     * @eventProperty
     */
    (event: "op", listener: (op: ISequencedDocumentMessage, local: boolean, target: IEventThisPlaceHolder) => void): any;
}

/* Excluded from this release type: makeHandlesSerializable */

/* Excluded from this release type: parseHandles */

/* Excluded from this release type: serializeHandles */

/* Excluded from this release type: SharedObject */

/* Excluded from this release type: SharedObjectCore */

/* Excluded from this release type: SummarySerializer */

/* Excluded from this release type: ValueType */

export { }
