/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { strict as assert } from "assert";
import { validateAssertionError } from "@fluidframework/test-runtime-utils";
import { SharedObject, SharedObjectCore } from "../sharedObject.js";
class MySharedObject extends SharedObject {
    constructor(id) {
        super(id, undefined, undefined, "");
    }
    summarizeCore(serializer) {
        throw new Error("Method not implemented.");
    }
    async loadCore(services) {
        throw new Error("Method not implemented.");
    }
    processCore(message, local, localOpMetadata) {
        throw new Error("Method not implemented.");
    }
    onDisconnect() {
        throw new Error("Method not implemented.");
    }
    applyStashedOp(content) {
        throw new Error("Method not implemented.");
    }
}
class MySharedObjectCore extends SharedObjectCore {
    constructor(id) {
        super(id, undefined, undefined);
        this.serializer = {};
    }
    summarizeCore(serializer) {
        throw new Error("Method not implemented.");
    }
    async loadCore(services) {
        throw new Error("Method not implemented.");
    }
    processCore(message, local, localOpMetadata) {
        throw new Error("Method not implemented.");
    }
    onDisconnect() {
        throw new Error("Method not implemented.");
    }
    applyStashedOp(content) {
        throw new Error("Method not implemented.");
    }
    getAttachSummary(fullTree, trackState) {
        throw new Error("Method not implemented.");
    }
    async summarize(fullTree, trackState) {
        throw new Error("Method not implemented.");
    }
    getGCData(fullGC) {
        throw new Error("Method not implemented.");
    }
}
describe("SharedObject", () => {
    it("rejects slashes in id", () => {
        const invalidId = "beforeSlash/afterSlash";
        const codeBlock = () => new MySharedObject(invalidId);
        assert.throws(codeBlock, (e) => validateAssertionError(e, "Id cannot contain slashes"));
    });
});
describe("SharedObjectCore", () => {
    it("rejects slashes in id", () => {
        const invalidId = "beforeSlash/afterSlash";
        const codeBlock = () => new MySharedObjectCore(invalidId);
        assert.throws(codeBlock, (e) => validateAssertionError(e, "Id cannot contain slashes"));
    });
});
//# sourceMappingURL=sharedObject.spec.js.map