/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { create404Response } from "@fluidframework/runtime-utils";
export class MockHandleContext {
    get IFluidHandleContext() {
        return this;
    }
    constructor(absolutePath = "", routeContext) {
        this.absolutePath = absolutePath;
        this.routeContext = routeContext;
        this.isAttached = false;
    }
    attachGraph() {
        throw new Error("Method not implemented.");
    }
    async resolveHandle(request) {
        return create404Response(request);
    }
}
/**
 * Creates a Jsonable object graph of a specified breadth/depth.  The 'createLeaf' callback
 * is a factory that is invoked to create the leaves of the graph.
 */
export function makeJson(breadth, depth, createLeaf) {
    let depthInternal = depth;
    if (--depthInternal === 0) {
        return createLeaf();
    }
    const o = {};
    for (let i = 0; i < breadth; i++) {
        o[`o${i}`] = makeJson(breadth, depthInternal, createLeaf);
    }
    return o;
}
//# sourceMappingURL=utils.js.map